==> coser-ui-1.1-sources.jar: fr/ifremer/coser/ui/selection/SpeciesTypesRenderer.java <==
/*
 * #%L
 * Coser :: UI
 * 
 * $Id: SpeciesTypesRenderer.java 404 2010-12-14 13:55:38Z chatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/coser/tags/coser-1.1/coser-ui/src/main/java/fr/ifremer/coser/ui/selection/SpeciesTypesRenderer.java $
 * %%
 * Copyright (C) 2010 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.coser.ui.selection;

import java.awt.Component;

import javax.swing.JList;

import org.apache.commons.lang.StringUtils;
import org.jdesktop.swingx.renderer.DefaultListRenderer;

import fr.ifremer.coser.ui.selection.model.SpeciesTypesListModel;

/**
 * Specy type renderer (with comment display when available).
 * 
 * @author chatellier
 * @version $Revision: 404 $
 * 
 * Last update : $Date: 2010-12-14 14:55:38 +0100 (mar., 14 déc. 2010) $
 * By : $Author: chatellier $
 */
public class SpeciesTypesRenderer extends DefaultListRenderer {

    /** serialVersionUID. */
    private static final long serialVersionUID = -6218097608544949959L;

    @Override
    public Component getListCellRendererComponent(JList list, Object value,
            int index, boolean isSelected, boolean cellHasFocus) {

        String species = (String)value;
        SpeciesTypesListModel model = (SpeciesTypesListModel)list.getModel();

        String comment = model.getComment(species);
        String stringValue = null;
        if (StringUtils.isEmpty(comment)) {
            stringValue = species;
        }
        else {
            stringValue = species + " (" + comment + ")"; 
        }

        return super.getListCellRendererComponent(list, stringValue, index, isSelected, cellHasFocus);
    }
    
}

==> coser-ui-1.2-sources.jar: fr/ifremer/coser/ui/selection/SpeciesTypesRenderer.java <==
/*
 * #%L
 * Coser :: UI
 * 
 * $Id: SpeciesTypesRenderer.java 932 2011-12-23 15:13:27Z echatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/coser/tags/coser-1.2/coser-ui/src/main/java/fr/ifremer/coser/ui/selection/SpeciesTypesRenderer.java $
 * %%
 * Copyright (C) 2010 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.coser.ui.selection;

import java.awt.Component;

import javax.swing.JList;

import org.apache.commons.lang3.StringUtils;
import org.jdesktop.swingx.renderer.DefaultListRenderer;

import fr.ifremer.coser.ui.selection.model.SpeciesTypesListModel;

/**
 * Specy type renderer (with comment display when available).
 * 
 * @author chatellier
 * @version $Revision: 932 $
 * 
 * Last update : $Date: 2011-12-23 16:13:27 +0100 (Fri, 23 Dec 2011) $
 * By : $Author: echatellier $
 */
public class SpeciesTypesRenderer extends DefaultListRenderer {

    /** serialVersionUID. */
    private static final long serialVersionUID = -6218097608544949959L;

    @Override
    public Component getListCellRendererComponent(JList list, Object value,
            int index, boolean isSelected, boolean cellHasFocus) {

        String species = (String)value;
        SpeciesTypesListModel model = (SpeciesTypesListModel)list.getModel();

        String comment = model.getComment(species);
        String stringValue = null;
        if (StringUtils.isEmpty(comment)) {
            stringValue = species;
        }
        else {
            stringValue = species + " (" + comment + ")"; 
        }

        return super.getListCellRendererComponent(list, stringValue, index, isSelected, cellHasFocus);
    }
    
}
